<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index15.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:41:01 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEOC - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo13.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage15-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader15">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader13.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header>
    <div class="header-area homepage15 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index1.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="404.html">SEO & Digital Marketing 01</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index2.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index2.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index2.html">SEO & Digital Marketing 02</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn25" href="index3.html" target="_blank">Multi Page <span></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn25" href="single-index3.html" target="_blank">One Page <span></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                               <div class="space20"></div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index4.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index4.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index4.html">SEO & Digital Marketing 04</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index5.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index5.html" target="_blank">One Page <span></span></a>
                                 </div>
                              </div>
                              <div class="homemenu-content">
                                <a href="index5.html">SEO & Digital Marketing 05</a>
                               </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index11.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index11.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index12.html" target="_blank"> Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index12.html" target="_blank"> One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn25" href="index13.html" target="_blank">Multi Page <span></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn25" href="single-index13.html" target="_blank"> One Page <span></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index14.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index14.html" target="_blank"> One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index15.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index15.html" target="_blank"> One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index6.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index6.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index6.html">SEO & Digital Marketing 06</a>
                                   </div>

                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index7.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index7.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index7.html">SEO & Digital Marketing 07</a>
                                   </div>

                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn25" href="index8.html" target="_blank">Multi Page <span></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn25" href="single-index8.html" target="_blank">One Page <span></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>

                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index9.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index9.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index9.html">SEO & Digital Marketing 09</a>
                                   </div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn25" href="index10.html" target="_blank">Multi Page <span></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn25" href="single-index10.html" target="_blank">One Page <span></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index10.html">SEO & Digital Marketing 10</a>
                                   </div>
                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>

              <div class="btn-area">
                <a href="#" class="login">Login</a>
                <a href="contact.html" class="header-btn24">Register Now </a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder15 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar15">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo2.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
   <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="404-5.html">Service One</a></li>
          <li><a href="404-6.html">Service Left</a></li>
          <li><a href="404-7.html">Service Right</a></li>
          <li><a href="404-8.html">Service Single</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="404-9.html">Case Study Left</a></li>
          <li><a href="404-10.html">Case Study Right</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn25">Get Started</a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero15-section-area">
    <img src="assets/img/bg/hero-bg3.png" alt="" class="hero-bg3">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="hero15-header">
                    <h5><span>New</span>Startups to Achieve Unprecedented Growth <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space20"></div>
                    <h1>Empowering Startups to Innovate & Thrive <img src="assets/img/elements/elementors37.png" alt="" class="keyframe5"></h1>
                    <div class="space24"></div>
                    <p>"We help startups scale, innovate, succeed with comprehensive suite of services tailored to fuel your business journey."</p>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="contact.html" class="header-btn25">Get Started Today</a>
                        <a href="https://www.youtube.com/watch?v=Y8XpQpW5OVY" class="header-btn25 btn2 popup-youtube"><i class="fa-solid fa-video"></i> Book A Free Consultation</a>
                    </div>
                    <div class="space32"></div>
                    <div class="author-area">
                        <img src="assets/img/all-images/new-img/authror-img1-h15.png" alt="">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li>5.0</li>
                            </ul>
                            <p>Rated Best Over <span>15.7k</span> Reviews</p>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
            <div class="images15-area">
                <div class="img1">
                    <img src="assets/img/all-images/new-img/header-img15.png" alt="">
                </div>
                <div class="elements-img">
                    <img src="assets/img/elements/elements32.png" alt="" class="elements32 aniamtion-key-1">
                    <img src="assets/img/elements/elements34.png" alt="" class="elements34 aniamtion-key-5">
                    <img src="assets/img/elements/elements35.png" alt="" class="elements35 aniamtion-key-2">
                    <img src="assets/img/elements/elements36.png" alt="" class="elements36 aniamtion-key-4">
                </div>
            </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->
<div class="others15-scetion-area sp4">
    <div class="container">
        <div class="row">
            <div class="col-lg-5">
                <div class="logo-content">
                    <img src="assets/img/logo/preloader13.png" alt="">
                    <p>SEOC has successfully collaborated with over 50 startups across various industries, helping them achieve remarkable growth and secure over $10 million in funding collectively.</p>
                </div>
            </div>
            <div class="col-lg-2">
                <span class="border"></span>
            </div>
            <div class="col-lg-5">
                <div class="others-counter-boxes">
                    <div class="counter-box">
                        <img src="assets/img/elements/elementors37.png" alt="">
                        <h2><span class="counter">24</span></h2>
                        <div class="space6"></div>
                        <p>Countries</p>
                    </div>

                    <div class="counter-box">
                        <img src="assets/img/elements/elementors38.png" alt="">
                        <h2><span class="counter">11</span>K</h2>
                        <div class="space6"></div>
                        <p>Participants</p>
                    </div>
                    <div class="counter-box">
                        <img src="assets/img/elements/elementors39.png" alt="">
                        <h2><span class="counter">10</span>K</h2>
                        <div class="space6"></div>
                        <p>Satisfied Client</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== ABOUT AREA STARTS =======-->
<div class="about15-section-area sp1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-3 col-md-6">
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/about-img1-h15.png" alt="">
                </div>
            </div>
            <div class="space30 d-md-none d-block"></div>
            <div class="col-lg-3 col-md-6">
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/about-img2-h15.png" alt="">
                </div>
                <div class="space30"></div>
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/about-img3-h15.png" alt="">
                </div>
            </div>
            <div class="col-lg-6">
                <div class="about15-header-area heading23">
                    <h5 data-aos="fade-left" data-aos-duration="800">About Us <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Empowering Startups with Expertise and Passion</h2>
                    <div class="space24"></div>
                    <p data-aos="fade-left" data-aos-duration="1000">We are passionate about helping startups thrive competitive market. Our team of seasoned strategists, designers, and digital marketers are dedicated to providing innovative solutions that drive real results. From concept to launch, we are your partners in growth."</p>
                    <div class="space8"></div>
                    <div class="list-area" data-aos="fade-left" data-aos-duration="1100">
                        <ul>
                            <li><img src="assets/img/icons/check16.svg" alt="">Innovation</li>
                            <li><img src="assets/img/icons/check16.svg" alt="">Collaboration</li>
                        </ul>
                        <ul>
                            <li><img src="assets/img/icons/check16.svg" alt="">Excellence</li>
                            <li><img src="assets/img/icons/check16.svg" alt="">Integrity</li>
                        </ul>
                    </div>
                    <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
                        <div class="space32"></div>
                        <a href="contact.html" class="header-btn25">Get Started</a>
                        <a href="about.html" class="header-btn24 btn2">See More</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-5 m-auto">
                <div class="service15-header text-center heading23 space-margin60">
                    <h5>Our Services <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Tailored Solutions for Every Stage of Your Startup</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service1-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Business Strategy </a>
                    <div class="space10"></div>
                    <p>Comprehensive business plans, market analysis, and go-to-market strategies to set your startup to success.</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service2-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Brand Identity & Design</a>
                    <div class="space10"></div>
                    <p>From logos to brand guidelines, we help you create a strong, cohesive brand your  Identity target audience.</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service3-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Design & Development</a>
                    <div class="space10"></div>
                    <p>"Responsive, user-friendly websites designed to enhance user experience & drive conversions."</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service4-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Digital Marketing & SEO</a>
                    <div class="space10"></div>
                    <p>"Data-driven marketing campaigns that boost visibility, engagement, growth across all digital platforms."</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service5-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Funding & Investor Decks</a>
                    <div class="space10"></div>
                    <p>"We craft compelling pitch decks that capture investor interest and secure the funding you need to grow."</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service6-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Content Creation </a>
                    <div class="space10"></div>
                    <p>"Craft powerful, persuasive content that tells your brand’s story, educates your audience, drives conversions."</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service7-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Product Development</a>
                    <div class="space10"></div>
                    <p>"Guide your product from concept to market strategic planning, prototyping, testing, and launch support."</p>
                </div>
            </div>
    
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="service15-boxarea">
                    <div class="icons">
                        <img src="assets/img/icons/service8-h15.svg" alt="">
                    </div>
                    <div class="space16"></div>
                    <a href="service1.html">Startup Mentorship  </a>
                    <div class="space10"></div>
                    <p>"Receive expert guidance and mentorship to navigate challenges, refine strategies, and scale startup effectively."</p>
                </div>
            </div>
            <div class="space20"></div>
            <div class="col-lg-12">
                <div class="btn-area1 text-center">
                    <a href="service1.html" class="header-btn25">View All Service</a>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== SERVICE AREA ENDS =======-->

<!--===== FEATURES AREA STARTS =======-->
<div class="features15-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-5 m-auto">
                <div class="features15-header text-center heading23 space-margin60">
                    <h5>Our Features <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Explore the Unique Features That Drive Our Clients' Success.</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-5" data-aos="zoom-in" data-aos-duration="800">
                <div class="features15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/features-img1-h15.png" alt="">
                    </div>
                    <div class="space24"></div>
                    <a href="service1.html">Transparent Communication and Collaboration</a>
                    <div class="space8"></div>
                    <p>"At SEOC, we value collaboration and transparency. We work closely with our clients, keeping them informed every step of the way and ensuring alwaysthe forefront."</p>
                </div>
            </div>
            <div class="col-lg-7" data-aos="zoom-in" data-aos-duration="900">
                <div class="features15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/features-img2-h15.png" alt="">
                    </div>
                    <div class="space24"></div>
                    <a href="service1.html">Tailored Solutions for Every Stage of Growth</a>
                    <div class="space8"></div>
                    <p>"From idea validation to scaling, we provide customized strategies that align with your startup's unique needs and goals. No matter where you are in your journey, our team develops a roadmap to success."</p>
                </div>
            </div>
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="features15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/features-img3-h15.png" alt="">
                    </div>
                    <div class="space24"></div>
                    <a href="service1.html">Data-Driven Decision Making</a>
                    <div class="space8"></div>
                    <p>"We believe in the power of data to guide strategy and decision-making. Our team craft campaigns that deliver measurable results and maximize ROI."</p>
                </div>
            </div>
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
                <div class="features15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/features-img4-h15.png" alt="">
                    </div>
                    <div class="space24"></div>
                    <a href="service1.html">Comprehensive Service Suite</a>
                    <div class="space8"></div>
                    <p>"SEOC offers an all-in-one solution for startups, covering everything from brand development and digital marketing to funding strategies and technical support.”</p>
                </div>
            </div>
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="features15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/features-img5-h15.png" alt="">
                    </div>
                    <div class="space24"></div>
                    <a href="service1.html">Proven Track Record of Success</a>
                    <div class="space8"></div>
                    <p>"We have helped numerous startups scale successfully, from securing initial funding to achieving sustainable growth. Our case studies client testimonials capability."</p>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== FEATURES AREA ENDS =======-->

<!--===== SKILLS AREA STARTS =======-->
<div class="skills15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6">
                <div class="skills-header heading23">
                    <h5 data-aos="fade-left" data-aos-duration="800">Agency Skills <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Discover a Comprehensive Suite  Startup’s Growth and Success</h2>
                    <div class="space24"></div>
                    <p data-aos="fade-left" data-aos-duration="1000">We specialize in providing a comprehensive range of services designed to empower startups at every stage of their journey. From crafting robust business strategies and building  vision into reality.</p>
                    <div class="space32"></div>
                    <div class="progress-bar" data-aos="fade-left" data-aos-duration="800">
                        <label>Branding <span>96%</span></label>
                        <div class="progress">
                            <div class="progress-inner" style="width: 96%;"></div>
                        </div>
                    </div>
                
                    <div class="progress-bar" data-aos="fade-left" data-aos-duration="900">
                        <label>Development <span>90%</span></label>
                        <div class="progress">
                            <div class="progress-inner" style="width: 90%;"></div>
                        </div>
                    </div>
                
                    <div class="progress-bar" data-aos="fade-left" data-aos-duration="1000">
                        <label>Advertising <span>70%</span></label>
                        <div class="progress">
                            <div class="progress-inner" style="width: 70%;"></div>
                        </div>
                    </div>
                
                    <div class="progress-bar" data-aos="fade-left" data-aos-duration="1100">
                        <label>Marketing <span>94%</span></label>
                        <div class="progress">
                            <div class="progress-inner" style="width: 94%;"></div>
                        </div>
                    </div>
                    <div class="space12"></div>
                    <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
                        <a href="service1.html" class="header-btn25">View All Service</a>
                    </div>
                </div>
            </div>
            <div class="col-lg-3 col-md-6">
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/skills-img1-h15.png" alt="">
                </div>
                <div class="space30 d-md-none d-block"></div>
            </div>
            <div class="col-lg-3 col-md-6">
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/skills-img2-h15.png" alt="">
                </div>
                <div class="space30"></div>
                <div class="img1 image-anime reveal">
                    <img src="assets/img/all-images/new-img/skills-img3-h15.png" alt="">
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== SKILLS AREA ENDS =======-->

<!--===== PROJECTS AREA STARTS =======-->
<div class="projects15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-4 m-auto">
                <div class="project15-header heading23 text-center space-margin60">
                    <h5>Work Showcase <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Some Featured Works</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="project15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/project-img1-h15.png" alt="">
                    </div>
                    <div class="btn-area1">
                        <a href="case-single.html" class="header-btn25">View Project</a>
                    </div>
                    <div class="space16"></div>
                    <div class="text-area">
                        <a href="case-single.html">Email Marketing</a>
                        <div class="space8"></div>
                        <p>Design - 2024</p>
                    </div>
                </div>
            </div>
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                <div class="project15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/project-img2-h15.png" alt="">
                    </div>
                    <div class="btn-area1">
                        <a href="case-single.html" class="header-btn25">View Project</a>
                    </div>
                    <div class="space16"></div>
                    <div class="text-area">
                        <a href="case-single.html">SEO & Digital Marketing</a>
                        <div class="space8"></div>
                        <p>Design - 2024</p>
                    </div>
                </div>
            </div>
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="project15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/project-img3-h15.png" alt="">
                    </div>
                    <div class="btn-area1">
                        <a href="case-single.html" class="header-btn25">View Project</a>
                    </div>
                    <div class="space16"></div>
                    <div class="text-area">
                        <a href="case-single.html">Flat Illustration</a>
                        <div class="space8"></div>
                        <p>Branding - 2024</p>
                    </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
                <div class="project15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/project-img4-h15.png" alt="">
                    </div>
                    <div class="btn-area1">
                        <a href="case-single.html" class="header-btn25">View Project</a>
                    </div>
                    <div class="space16"></div>
                    <div class="text-area">
                        <a href="case-single.html">Technology & It Solution</a>
                        <div class="space8"></div>
                        <p>Design - 2024</p>
                    </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="project15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/project-img5-h15.png" alt="">
                    </div>
                    <div class="btn-area1">
                        <a href="case-single.html" class="header-btn25">View Project</a>
                    </div>
                    <div class="space16"></div>
                    <div class="text-area">
                        <a href="case-single.html">Crypto Currency</a>
                        <div class="space8"></div>
                        <p>Design - 2024</p>
                    </div>
                </div>
            </div>
            <div class="col-lg-12">
                <div class="space20"></div>
                <div class="btn-area1 text-center">
                    <a href="case.html" class="header-btn25">View All Works</a>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== PROJECTS AREA ENDS =======-->

<!--===== OTHERS AREA STARTS =======-->
<div class="others15-author-section sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="others-header text-center heading23 space-margin60">
                    <h5>Our Clients & Partners <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2>Integrations for Every Workflow</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-10 m-auto">
                <div class="row">
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements37.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements38.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements39.png" alt="">
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements40.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements41.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements42.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements43.png" alt="">
                        </div>
                    </div>
        
                    <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                        <div class="others-boxarea">
                            <img src="assets/img/elements/elements44.png" alt="">
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== OTHERS AREA ENDS =======-->

<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-4 m-auto">
                <div class="testimonial-header text-center heading23 space-margin60">
                    <h5>Testimonials <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">What Our Client Say</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12">
                <div class="testimonial-slider-boxarea">
                    <img src="assets/img/logo/preloader13.png" alt="" class="preloader13">
                    <div class="row">
                        <div class="col-lg-1"></div>
                        <div class="col-lg-4">
                            <div class="testimonial-author-box">
                                <h3>5.0 <i class="fa-solid fa-star"></i></h3>
                                <p>50+ Review</p>
                                <div class="space24"></div>
                                <h2 class="text-anime-style-3">Helping World-Class Comany by Creative Design.</h2>
                            </div>
                        </div>
                        <div class="col-lg-1"></div>
                        <div class="col-lg-6">
                            <div class="testimonial15-slider owl-carousel">
                                <div class="testimonial-boxarea">
                                    <img src="assets/img/elements/elements45.png" alt="" class="elements45">
                                    <div class="space32"></div>
                                    <p>"The SEOC team truly understands the startup ecosystem. Their comprehensive services, from website development to investor pitch decks, were invaluable. They helped us present our company’s vision clearly compellingly, resulting in a successful A funding round."</p>
                                    <div class="space60"></div>
                                    <div class="name-area">
                                        <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                                        <div class="text">
                                            <a href="#">Micheal Gough</a>
                                            <p>CTO at Microsoft</p>
                                        </div>
                                    </div>
                                </div>
                                <div class="testimonial-boxarea">
                                    <img src="assets/img/elements/elements45.png" alt="" class="elements45">
                                    <div class="space32"></div>
                                    <p>"The SEOC team truly understands the startup ecosystem. Their comprehensive services, from website development to investor pitch decks, were invaluable. They helped us present our company’s vision clearly compellingly, resulting in a successful A funding round."</p>
                                    <div class="space60"></div>
                                    <div class="name-area">
                                        <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                                        <div class="text">
                                            <a href="#">Micheal Gough</a>
                                            <p>CTO at Microsoft</p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-8 m-auto">
                <div class="blog15-header text-center heading23 space-margin60">
                    <h5>Our Blog & News <i class="fa-solid fa-angle-right"></i></h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">"Insights, Tips, & Trends for Startup Success"</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4" data-aos="fade-left" data-aos-duration="800">
                <div class="blog15-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img1-h15.png" alt="">
                    </div>
                    <div class="space16"></div>
                    <ul>
                        <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 16 August 2023</a></li>
                        <li class="m-0"><a href="#"><i class="fa-regular fa-user"></i> Ben Stokes</a></li>
                    </ul>
                    <div class="space16"></div>
                    <a href="blog-single.html" class="head">The Ultimate Guide Launching a Successful Startup Agency</a>
                    <div class="space16"></div>
                    <p>Launching a startup is both exciting challenging. From idea validation to product-market fit and scaling strategies, this guide covers everything you need to know to turn your thriving business.</p>
                    <div class="space16"></div>
                    <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                </div>
                <div class="space30"></div>
            </div>
            <div class="col-lg-4 col-md-6">
                <div class="blog-author-boxarea">
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="800">
                        <a href="blog-single.html" class="head">How to Create a Winning Pitch Deck that Attracts </a>
                        <div class="space16"></div>
                        <p>"A compelling pitch deck is crucial for securing funding. Learn the key elements that make a pitch deck stand out, common pitfalls to avoid, and tips to captivate your audience.</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                    <div class="space30"></div>
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="1000">
                        <a href="blog-single.html" class="head">Growth Marketing Strategies Early-Stage Startups</a>
                        <div class="space16"></div>
                        <p>Growth marketing is all about data-driven experimentation and optimization. Discover the top 10 strategies that helped startups grow exponentially and how to apply them.</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                    <div class="space30"></div>
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="1200">
                        <a href="blog-single.html" class="head">Why It Matters and How to Do It Right</a>
                        <div class="space16"></div>
                        <p>our brand identity is more than just a logo; it’s the perception people have of your business. Learn how to craft a strong, memorable brand identity that resonates with competitors.</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
            
            <div class="col-lg-4 col-md-6">
                <div class="space30 d-md-none d-block"></div>
                <div class="blog-author-boxarea">
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="800">
                        <a href="blog-single.html" class="head">Startup Lessons from Founders Who Made It Big</a>
                        <div class="space16"></div>
                        <p>The startup journey is filled with ups and downs. In this blog, we share stories and lessons from successful founders who overcame major challenges  businesses."</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                    <div class="space30"></div>
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="1000">
                        <a href="blog-single.html" class="head">Leveraging Data Analytics to Drive Startup Growth</a>
                        <div class="space16"></div>
                        <p>Data is the new oil in the startup world. Explore how to leverage data analytics to understand customer behavior, optimize marketing efforts, drive sustainable growth."</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                    <div class="space30"></div>
                    <div class="blog-box" data-aos="fade-left" data-aos-duration="1200">
                        <a href="blog-single.html" class="head">Essential Tools and Platforms Every Startup Needs</a>
                        <div class="space16"></div>
                        <p>Choosing the right tools and platforms can significantly impact your startup’s efficiency and growth. Here’s a list of essential tools for project management, marketing automation.</p>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="readmore">Read More <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta15-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="cta-header-area text-center">
                    <h2 class="text-anime-style-3">Sign Up For Our Newsletter</h2>
                    <div class="space16"></div>
                    <p data-aos="fade-left" data-aos-duration="1000">Stay up to date with the roadmap progress, announcements and exclusive discounts feel free to sign up with your email.</p>
                   <div class="space32"></div>
                    <form data-aos="fade-left" data-aos-duration="1100">
                        <input type="email" placeholder="Enter Your Email">
                        <i><i class="fa-regular fa-envelope"></i></i>
                        <button class="header-btn25">Subscribe</button>
                    </form>
                    <div class="space12"></div>
                    <span>We care about the protection of your data. Read our <a href="#">Privacy Policy.</a> </span>
                </div>
            </div>
        </div>
    </div>
</div>
  <!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer15-section-area sp8">
    <div class="container">
        <div class="row">
            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>Quick Links </h2>
                    <ul>
                        <li><a href="index.html">Home </a></li>
                        <li><a href="about.html">About Us </a></li>
                        <li><a href="service1.html">Services </a></li>
                        <li><a href="blog.html">Blog  </a></li>
                        <li><a href="testimonials.html">Testimonials  </a></li>
                    </ul>
                </div>
            </div>
            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>Our services</h2>
                    <ul>
                        <li><a href="#">Business Strategy </a></li>
                        <li><a href="#">Content Creation </a></li>
                        <li><a href="#">Product Development</a></li>
                        <li><a href="#">Design & Development</a></li>
                        <li><a href="#">Startup Mentorship</a></li>
                    </ul>
                </div>
            </div>
            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>Resources</h2>
                    <ul>
                        <li><a href="faq.html">FAQ’S</a></li>
                        <li><a href="case.html">Case Studies</a></li>
                        <li><a href="#">Startup Toolkit</a></li>
                        <li><a href="#">Ebooks And Guides</a></li>
                        <li><a href="#">Startup Mentorship</a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>Auick Services</h2>
                    <ul>
                        <li><a href="#">Ui Design</a></li>
                        <li><a href="#">Web Design</a></li>
                        <li><a href="#">Branding</a></li>
                        <li><a href="#">Webflow</a></li>
                        <li><a href="#">Development</a></li>
                    </ul>
                </div>
            </div>
            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>New York</h2>
                    <ul>
                        <li><a href="#">1447 Street Charleston 
                            New York</a></li>
                        <li><a href="tel:+2258-254-257">+2 258-254-257</a></li>
                        <li><a href="mailto:info@seocagency.com">info@seocagency.com</a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-2 col-md-4 col-6">
                <div class="footer-link-area">
                    <h2>London</h2>
                    <ul>
                        <li><a href="#">857 Street Western 
                            London</a></li>
                        <li><a href="tel:+2258-254-257">+2 258-254-257</a></li>
                        <li><a href="mailto:info@seocagency.com">info@seocagency.com</a></li>
                    </ul>
                </div>
            </div>
        </div>
        <div class="space50"></div>
        <div class="row">
            <div class="col-lg-12">
                <div class="footer-logo-area">
                    <img src="assets/img/logo/logo16.png" alt="">
                    <p>© 2024 SEOC, Inc. All Rights Reserved.</p>
                    <ul>
                        <li><a href="#"><i class="fa-brands fa-github"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-twitter"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-dribbble"></i></a></li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== FOOTER AREA ENDS =======-->

<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index15.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:41:22 GMT -->
</html>